==> owncloud-8.1.0p2.tgz: owncloud/apps/activity/l10n/lv.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Izmaiņas",
    "Personal activity feed for %s" : "%s personīgā izmaiņu plūsma ",
    "Your feed URL is invalid" : "Jūsu plūsmas URL nav derīgs.",
    "Your settings have been updated." : "Jūsu uzstādījumi ir atjaunoti.",
    "This stream will show events like additions, changes & shares" : "Šajā straumē tiks parādītas koplietošanas, dalīšanās un citi notikumi.",
    "There are no events for this filter" : "Šim filtram nav notikumu",
    "Activity notification" : "Brīdinājumi par izmaiņām",
    "All Activities" : "Visas izmaiņas",
    "Activities by you" : "Tevis veiktās izmaiņas",
    "Activities by others" : "Citu veiktās izmaiņas",
    "\"remote user\"" : "\"attālināts lietotājs\"",
    "in %s" : "%s",
    "%s and %s" : "%s un %s",
    ", " : ",",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s un <strong class=\"tooltip\" title=\"%s\">vēl %n</strong>","%s un <strong class=\"tooltip\" title=\"%s\">vēl %n</strong>","%s un <strong class=\"tooltip\" title=\"%s\">vēl %n</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s un vēl %n","%s un vēl %n","%s un vēl %n"],
    "Hello %s," : "Sveicināti %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Jūs saņemat šo e-pastu, jo pēdējās stundas laikā %s ir notikušās šādas izmaiņas:",
    "You are receiving this email because in the last day the following things happened at %s" : "Jūs saņemat šo e-pastu, jo pēdējās diennakts laikā %s ir notikušas šādas izmaiņas:",
    "You are receiving this email because in the last week the following things happened at %s" : "Jūs saņemat šo e-pastu, jo pēdējās nedēļas laikā %s ir notikušas šādas izmaiņas:",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["*","* un vēl %n","* un vēl %n"],
    "Notifications" : "Paziņojumi",
    "Mail" : "E-pasts",
    "Stream" : "Datu straume",
    "List your own actions in the stream" : "Parādīt sarakstā savas veiktās darbības",
    "Notify about your own actions via email" : "Paziņot par savām darbībām, izmantojot e-pastu",
    "You need to set up your email address before you can receive notification emails." : "Vispirms profilam ir nepieciešams uzstādīt e-pasta adresi, lai pa to saņemtu paziņojumus.",
    "Send emails:" : "E-pastus sūtīt:",
    "Hourly" : "Ik stundu",
    "Daily" : "Katru dienu",
    "Weekly" : "Katru nedēļu",
    "Activity feed" : "Izmaiņu plūsma",
    "Enable RSS feed" : "Ieslēgt RSS plūsmu",
    "No activity yet" : "Vēl nav aktivitāšu",
    "No more events to load" : "Nav vairs notikumu, ko ielādēt",
    "Files" : "Datnes"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> owncloud-9.0.3.tgz: owncloud/apps/activity/l10n/lv.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Izmaiņas",
    "Personal activity feed for %s" : "%s personīgā izmaiņu plūsma ",
    "Your feed URL is invalid" : "Jūsu plūsmas URL nav derīgs.",
    "Your settings have been updated." : "Jūsu uzstādījumi ir atjaunoti.",
    "Mail" : "E-pasts",
    "Stream" : "Datu straume",
    ", " : ",",
    "This stream will show events like additions, changes & shares" : "Šajā straumē tiks parādītas koplietošanas, dalīšanās un citi notikumi.",
    "There are no events for this filter" : "Šim filtram nav notikumu",
    "Today" : "Šodien",
    "Yesterday" : "Vakar",
    "\"remote user\"" : "\"attālināts lietotājs\"",
    "Activity notification" : "Brīdinājumi par izmaiņām",
    "All Activities" : "Visas izmaiņas",
    "Activities by you" : "Tevis veiktās izmaiņas",
    "Activities by others" : "Citu veiktās izmaiņas",
    "%s and %s" : "%s un %s",
    "Hello %s," : "Sveicināti %s,",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["*","* un vēl %n","* un vēl %n"],
    "List your own actions in the stream" : "Parādīt sarakstā savas veiktās darbības",
    "Notify about your own actions via email" : "Paziņot par savām darbībām, izmantojot e-pastu",
    "You need to set up your email address before you can receive notification emails." : "Vispirms profilam ir nepieciešams uzstādīt e-pasta adresi, lai pa to saņemtu paziņojumus.",
    "Send emails:" : "E-pastus sūtīt:",
    "Hourly" : "Ik stundu",
    "Daily" : "Katru dienu",
    "Weekly" : "Katru nedēļu",
    "Activity feed" : "Izmaiņu plūsma",
    "Enable RSS feed" : "Ieslēgt RSS plūsmu",
    "No activity yet" : "Vēl nav aktivitāšu",
    "No more events to load" : "Nav vairs notikumu, ko ielādēt",
    "Files" : "Datnes"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
